# Generated by Django 5.2.9 on 2026-02-03 09:05

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('wbcommission', '0012_commission_root_account'),
    ]

    operations = [
        migrations.AlterField(
            model_name='commissionrule',
            name='consider_zero_percent_for_exclusion',
            field=models.BooleanField(default=True, help_text='If true, the commission rule with percent 0 (initially consider disabled), will be considered for exclusion rule matching', verbose_name='Consider 0 percent for exclusion'),
        ),
    ]
